# react-gui

[![npm version](https://img.shields.io/npm/v/react-gui.svg?style=flat)](https://www.npmjs.com/package/react-gui)

A framework for creating accessible, interactive, responsive apps with React.

React GUI uses modern React features to provide a consistent set of UX primitives for working with views, events, gestures, and other behaviors. The built-in Hooks allow for easy composition of behaviors and support the implementation of the [WAI-ARIA Authoring Practices](https://www.w3.org/TR/wai-aria-practices-1.2/).

## Requirements

* `node@>=12.15`: Import paths documented for this package rely on [Node.js package entry points](https://nodejs.org/api/packages.html#packages_package_entry_points). Make sure your bundler also supports this Node API (e.g., `webpack@>=5`).

* `react-dom@experimental`: Works best with React DOM's `createRoot` and `createBlockingRoot` APIs, which are curently available only in the experimental builds.

* Browsers: Chrome, Safari 11+, Edge, Firefox, Opera, IE 11.

## Installation

```
npm install react-gui
```

## API

### Components

The foundational components are adapted from those used in React Native today. These components can adopt behaviors by linking refs to the event and interaction hooks.

* [View](./src/view)
* [Text](./src/text)
* [Image](./src/image)
* [TextInput](./src/text-input)
* [TextArea](./src/text-area)
* [RichTextArea](./src/rich-text-area)

### APIs

* [StyleSheet](./src/style-sheet)

### Interactions

High-level interactions that simplify working with accessible behaviors across devices and platforms. These hooks (and the underlying event hooks) make it easy to work with pointer gestures, keyboard interactions, and layout changes to adjust a component's render tree and styles. The interaction hooks cause a component to update when their return value changes (if this is not desired, use the event hooks).

* [useFocus](./src/use-focus)
* [useFocusVisibility](./src/use-focus-visibility)
* [useFocusWithin](./src/use-focus-within)
* [useHover](./src/use-hover)
* [useInteractOutside](./src/use-interact-outside)
* [useKeyboard](./src/use-keyboard)
* [useLayout](./src/use-layout)
* [useModality](./src/use-modality)
* [usePan](./src/use-pan)
* [usePress](./src/use-press)
* [useResponder](./src/use-responder)

### Other hooks

* [useFileSelector](./src/use-file-selector)
* [useMergeRefs](./src/use-merge-refs)
* [usePreferences](./src/use-preferences)

### Imperative methods

Methods for working imperatively with host elements.

* [blur](./src/utils#blur)
* [clear](./src/utils#clear)
* [focus](./src/utils#focus)
* [getLayoutRect](./src/utils#getLayoutRect)
* [getActiveModality](./src/utils#getActiveModality)
* [getModality](./src/utils#getModality)

### Unstable DOM APIs

These unstable APIs are the DOM-specific abstractions used to create the built-in, platform-agnostic APIs.

* [createElement](./src/create-element)
* [createEventHandle](./src/create-event-handle)
* [useEvent](./src/use-event)

## Other

[CONTRIBUTING](./.github/workflows/CONTRIBUTING.md)
