"use strict";

exports.__esModule = true;
exports.Image = void 0;

var React = _interopRequireWildcard(require("react"));

var _createElement = require("../create-element");

var _useEvent = require("../use-event");

var _useMergeRefs = require("../use-merge-refs");

var _TextAncestorContext = _interopRequireDefault(require("../text/TextAncestorContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var ERROR_PLACEHOLDER = 'data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw==';
var Image = /*#__PURE__*/React.forwardRef(function (props, forwardedRef) {
  var accessibilityDescribedBy = props.accessibilityDescribedBy,
      accessibilityDetails = props.accessibilityDetails,
      accessibilityHasPopup = props.accessibilityHasPopup,
      accessibilityHidden = props.accessibilityHidden,
      accessibilityLabel = props.accessibilityLabel,
      accessibilityLabelledBy = props.accessibilityLabelledBy,
      accessibilityOwns = props.accessibilityOwns,
      accessibilityPressed = props.accessibilityPressed,
      accessibilityRole = props.accessibilityRole,
      accessibilityRoleDescription = props.accessibilityRoleDescription,
      accessibilitySelected = props.accessibilitySelected,
      alternativeText = props.alternativeText,
      crossOrigin = props.crossOrigin,
      dataSet = props.dataSet,
      _props$decoding = props.decoding,
      decoding = _props$decoding === void 0 ? 'auto' : _props$decoding,
      _props$draggable = props.draggable,
      draggable = _props$draggable === void 0 ? false : _props$draggable,
      focusable = props.focusable,
      loading = props.loading,
      nativeID = props.nativeID,
      onError = props.onError,
      onLoad = props.onLoad,
      referrerPolicy = props.referrerPolicy,
      source = props.source,
      style = props.style,
      testID = props.testID;
  var addLoadListener = (0, _useEvent.useEvent)('load');
  var addErrorListener = (0, _useEvent.useEvent)('error');
  var hasTextAncestor = React.useContext(_TextAncestorContext.default); // If the image fails to load, browsers will display a "broken" icon.
  // To avoid this we replace the image with a transparent gif.

  var internalImageRef = React.useCallback(function (image) {
    if (image != null) {
      addErrorListener(image, function () {
        setManagedSrc(ERROR_PLACEHOLDER);

        if (onError != null) {
          onError();
        }
      });
      addLoadListener(image, function (e) {
        var target = e.target;

        if (target.src === ERROR_PLACEHOLDER) {
          // Prevent the placeholder from triggering a 'load' event
          // that event listeners would otherwise receive.
          e.stopImmediatePropagation();
        } else if (onLoad != null) {
          var naturalWidth = target.naturalWidth,
              naturalHeight = target.naturalHeight,
              width = target.width,
              height = target.height,
              currentSrc = target.currentSrc,
              _src = target.src;
          onLoad({
            naturalWidth: naturalWidth,
            naturalHeight: naturalHeight,
            width: width,
            height: height,
            currentSource: currentSrc != null ? currentSrc : _src
          });
        }
      });
    }
  }, [addErrorListener, addLoadListener, onError, onLoad]);
  var ref = (0, _useMergeRefs.useMergeRefs)(internalImageRef, forwardedRef);
  var src;
  var srcSet;

  if (typeof source === 'string') {
    src = source;
  } else if (source != null && source.uri) {
    src = source.uri;
  } else if (Array.isArray(source)) {
    src = source[0].uri;
    srcSet = source.map(function (_ref) {
      var uri = _ref.uri,
          scale = _ref.scale;
      return uri + " " + (scale || 1) + "x";
    });
  }

  var _React$useState = React.useState(src),
      managedSrc = _React$useState[0],
      setManagedSrc = _React$useState[1]; // Construct the element


  var element = (0, _createElement.createElement)('img', {
    accessibilityDescribedBy: accessibilityDescribedBy,
    accessibilityDetails: accessibilityDetails,
    accessibilityHasPopup: accessibilityHasPopup,
    accessibilityHidden: accessibilityHidden,
    accessibilityLabel: accessibilityLabel,
    accessibilityLabelledBy: accessibilityLabelledBy,
    accessibilityOwns: accessibilityOwns,
    accessibilityPressed: accessibilityPressed,
    accessibilityRole: accessibilityRole,
    accessibilityRoleDescription: accessibilityRoleDescription,
    accessibilitySelected: accessibilitySelected,
    alt: alternativeText,
    classList: hasTextAncestor ? inlineClassList : defaultClassList,
    crossOrigin: crossOrigin,
    dataSet: dataSet,
    decoding: decoding,
    draggable: draggable,
    focusable: focusable,
    loading: loading,
    nativeID: nativeID,
    ref: ref,
    referrerPolicy: referrerPolicy,
    src: managedSrc,
    srcSet: srcSet != null && managedSrc !== ERROR_PLACEHOLDER ? srcSet.join(',') : null,
    style: style,
    testID: testID
  });
  return element;
});
exports.Image = Image;
Image.displayName = 'Image';
var classes = (0, _createElement.createStyleRules)({
  image: {
    backgroundColor: 'transparent',
    border: '0 solid black',
    boxSizing: 'border-box',
    display: 'flex',
    flexDirection: 'column',
    flexShrink: 0,
    margin: 0,
    minHeight: 0,
    minWidth: 0,
    objectFit: 'cover',
    padding: 0,
    position: 'relative',
    zIndex: 0
  },
  inlineImage: {
    display: 'inline-flex'
  }
});
var defaultClassList = [classes.image];
var inlineClassList = [classes.image, classes.inlineImage];