"use strict";

exports.__esModule = true;
exports.Text = void 0;

var React = _interopRequireWildcard(require("react"));

var _createElement = require("../create-element");

var _getAccessibilityElementWithSideEffect = _interopRequireDefault(require("../../modules/getAccessibilityElementWithSideEffect"));

var _TextAncestorContext = _interopRequireDefault(require("./TextAncestorContext"));

var _constants = require("../style-sheet/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Nicolas Gallagher.
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var Text = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var children = props.children,
      direction = props.direction,
      href = props.href,
      hrefAttrs = props.hrefAttrs,
      lang = props.lang;
  var hasTextAncestor = React.useContext(_TextAncestorContext.default); // Don't render a DOM node wrapper if this element is nested within another Text,
  // and it has no props or ref set.

  if (hasTextAncestor && ref == null) {
    var propsLength = Object.keys(props).length;

    if (propsLength === 0) {
      return null;
    } else if (props.children != null && propsLength === 1) {
      return props.children;
    }
  } // Construct the props


  var elementProps = (0, _createElement.filterProps)(props);
  elementProps.children = children;
  elementProps.classList = hasTextAncestor ? inlineClassList : defaultClassList; // Only set the dir to 'auto' for root text elements, unless it is explicit
  // set via props.

  elementProps.dir = direction;

  if (!hasTextAncestor && direction == null) {
    elementProps.dir = 'auto';
  }

  elementProps.lang = lang;
  elementProps.ref = ref;

  if (href) {
    elementProps.href = href;

    if (hrefAttrs != null) {
      var download = hrefAttrs.download,
          rel = hrefAttrs.rel,
          target = hrefAttrs.target;

      if (download != null) {
        elementProps.download = download;
      }

      if (rel != null) {
        elementProps.rel = rel;
      }

      if (typeof target === 'string' && target.charAt(0) !== '_') {
        elementProps.target = '_' + target;
      }
    }
  } // Construct the element


  var accessibilityElementType = (0, _getAccessibilityElementWithSideEffect.default)(elementProps);
  var elementType = accessibilityElementType || (hasTextAncestor ? 'span' : 'div');
  var element = (0, _createElement.createElement)(elementType, elementProps);
  return hasTextAncestor ? element : /*#__PURE__*/React.createElement(_TextAncestorContext.default.Provider, {
    value: true
  }, element);
});
exports.Text = Text;
Text.displayName = 'Text';
var classes = (0, _createElement.createStyleRules)({
  text: {
    backgroundColor: 'transparent',
    border: '0 solid black',
    boxSizing: 'border-box',
    color: 'black',
    display: 'inline',
    font: "14px " + _constants.SYSTEM_FONT_STACK,
    margin: 0,
    padding: 0,
    textDecoration: 'none',
    whiteSpace: 'pre-wrap',
    wordWrap: 'break-word'
  },
  textHasAncestor: {
    color: 'inherit',
    font: 'inherit',
    whiteSpace: 'inherit'
  }
});
var defaultClassList = [classes.text];
var inlineClassList = [classes.text, classes.textHasAncestor];