"use strict";

exports.__esModule = true;
exports.useFileSelect = useFileSelect;

var _react = _interopRequireDefault(require("react"));

var _supportsDOM = _interopRequireDefault(require("../../modules/supportsDOM"));

var _useLayoutEffect = _interopRequireDefault(require("../../modules/useLayoutEffect"));

var _useStable = _interopRequireDefault(require("../../modules/useStable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
function createInput() {
  if ((0, _supportsDOM.default)()) {
    var input = document.createElement('input');
    input.type = 'file';
    return input;
  }
}

function clearInput(input) {
  input.value = '';
}

function processAcceptTypes(acceptTypes) {
  return acceptTypes.map(function (fileType) {
    if (fileType.indexOf('/') !== -1 || fileType[0] === '.') {
      return fileType;
    }

    console.error("useFileSelector: \"acceptType\" value of " + fileType + " is not a valid MIME type or file extension.", 'File extensions must start with a "." character.');
  }).join(',');
}

function useFileSelect(config) {
  var acceptMultiple = config.acceptMultiple,
      acceptTypes = config.acceptTypes,
      onFilesChange = config.onFilesChange,
      source = config.source;
  var input = (0, _useStable.default)(createInput);

  var openFileSelector = _react.default.useCallback(function () {
    if (input != null) {
      input.click();
    }
  }, [input]);

  var onChange = _react.default.useCallback(function (e) {
    e.preventDefault();

    if (e.target instanceof HTMLInputElement) {
      onFilesChange(Array.from(e.target.files));

      if (input != null) {
        clearInput(input);
      }
    }
  }, [input, onFilesChange]);

  (0, _useLayoutEffect.default)(function () {
    if (input == null) {
      return;
    }

    var accept = acceptTypes != null ? processAcceptTypes(acceptTypes) : null;

    if (accept != null) {
      input.setAttribute('accept', accept);
    }

    if (source != null) {
      input.setAttribute('capture', source);
    }

    if (acceptMultiple != null) {
      input.setAttribute('multiple', String(acceptMultiple));
    } // $FlowExpectedError: sigh


    input.addEventListener('change', onChange);
    return function () {
      // $FlowExpectedError: sigh
      input.removeEventListener('change', onChange);
    };
  }, [acceptMultiple, acceptTypes, source, onChange, input]);
  return openFileSelector;
}