"use strict";

exports.__esModule = true;
exports.useFocusWithin = useFocusWithin;

var _react = _interopRequireDefault(require("react"));

var _addEvent = require("../../modules/addEvent");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useFocusWithin implementation
 */
var passiveOptions = {
  passive: true
};

function useFocusWithin(config) {
  var disabled = config.disabled,
      onBlurWithin = config.onBlurWithin,
      onFocusWithin = config.onFocusWithin,
      onFocusWithinChange = config.onFocusWithinChange;

  var attachedNode = _react.default.useRef(null);

  var focusWithinRef = _react.default.useRef(false);

  return _react.default.useCallback(function (target) {
    var focusInListener = function focusInListener(e) {
      if (disabled) {
        return;
      }

      if (onFocusWithin != null) {
        onFocusWithin(e);
      }

      if (focusWithinRef.current === false) {
        focusWithinRef.current = true;

        if (onFocusWithinChange != null) {
          onFocusWithinChange(true);
        }
      }
    };

    var focusOutListener = function focusOutListener(e) {
      if (disabled) {
        return;
      }

      if (onBlurWithin != null) {
        onBlurWithin(e);
      }

      if (focusWithinRef.current === true && target != null && target instanceof HTMLElement) {
        // Ignore focus moving within the subtree
        if (!target.contains(e.relatedTarget)) {
          focusWithinRef.current = false;

          if (onFocusWithinChange) {
            onFocusWithinChange(false);
          }
        }
      }
    };

    if (target !== null) {
      (0, _addEvent.addEvent)(target, 'focusin', focusInListener, passiveOptions);
      (0, _addEvent.addEvent)(target, 'focusout', focusOutListener, passiveOptions);
    } else if (attachedNode.current != null) {
      var node = attachedNode.current;
      (0, _addEvent.removeEvent)(node, 'focusin', focusInListener, passiveOptions);
      (0, _addEvent.removeEvent)(node, 'focusout', focusOutListener, passiveOptions);
      attachedNode.current = null;
    }
  }, [disabled, onBlurWithin, onFocusWithin, onFocusWithinChange]);
}