"use strict";

exports.__esModule = true;
exports.useFocus = useFocus;

var _react = _interopRequireDefault(require("react"));

var _addEvent = require("../../modules/addEvent");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useFocusEvents implementation
 */
var bubbleOptions = {
  passive: true
};
var captureOptions = {
  capture: true,
  passive: true
};

function useFocus(config) {
  var disabled = config.disabled,
      onBlur = config.onBlur,
      onBlurCapture = config.onBlurCapture,
      onFocus = config.onFocus,
      onFocusCapture = config.onFocusCapture,
      onFocusChange = config.onFocusChange;

  var attachedNode = _react.default.useRef(null);

  return _react.default.useCallback(function (target) {
    function blurListener(e) {
      if (disabled) {
        return;
      }

      if (onBlur != null) {
        onBlur(e);
      }

      if (onFocusChange != null) {
        onFocusChange(false, e);
      }
    }

    function focusListener(e) {
      if (disabled) {
        return;
      }

      if (onFocus != null) {
        onFocus(e);
      }

      if (onFocusChange != null) {
        onFocusChange(true, e);
      }
    }

    if (target !== null) {
      attachedNode.current = target;
      (0, _addEvent.addEvent)(target, 'blur', blurListener, bubbleOptions);
      (0, _addEvent.addEvent)(target, 'focus', focusListener, bubbleOptions);

      if (onBlurCapture != null) {
        (0, _addEvent.addEvent)(target, 'blur', !disabled && onBlurCapture || null, captureOptions);
      }

      if (onFocusCapture != null) {
        (0, _addEvent.addEvent)(target, 'focus', !disabled && onFocusCapture || null, captureOptions);
      }
    } else if (attachedNode.current != null) {
      var node = attachedNode.current;
      (0, _addEvent.removeEvent)(node, 'blur', blurListener, bubbleOptions);
      (0, _addEvent.removeEvent)(node, 'focus', focusListener, bubbleOptions);
      (0, _addEvent.removeEvent)(node, 'blur', onBlurCapture, captureOptions);
      (0, _addEvent.removeEvent)(node, 'focus', onFocusCapture, captureOptions);
      attachedNode.current = null;
    }
  }, [disabled, onBlur, onBlurCapture, onFocus, onFocusCapture, onFocusChange]);
}