"use strict";

exports.__esModule = true;
exports.useHover = useHover;

var _react = _interopRequireDefault(require("react"));

var _addEvent = require("../../modules/addEvent");

var _modality = require("../../modules/modality");

var _dispatchCustomEvent = _interopRequireDefault(require("../../modules/dispatchCustomEvent"));

var _supportsPointerEvent = _interopRequireDefault(require("../../modules/supportsPointerEvent"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * Implementation
 */
var opts = {
  passive: true
};
var lockEventType = 'react-gui:hover:lock';
var unlockEventType = 'react-gui:hover:unlock'; // This accounts for the non-PointerEvent fallback events.

function getPointerType(event) {
  var pointerType = event.pointerType;
  return pointerType != null ? pointerType : (0, _modality.getModality)();
}

function useHover(config) {
  var bubbles = config.bubbles,
      disabled = config.disabled,
      onHoverStart = config.onHoverStart,
      onHoverChange = config.onHoverChange,
      onHoverUpdate = config.onHoverUpdate,
      onHoverEnd = config.onHoverEnd;

  var attachedNode = _react.default.useRef(null);

  var canUsePE = (0, _supportsPointerEvent.default)();
  return _react.default.useCallback(function (target) {
    var enterEventType = canUsePE ? 'pointerenter' : 'mouseenter';
    var moveEventType = canUsePE ? 'pointermove' : 'mousemove';
    var leaveEventType = canUsePE ? 'pointerleave' : 'mouseleave';
    /**
     * "Bubbling" controllers
     */

    var lockListener = function lockListener(lockEvent) {
      if (disabled) {
        return;
      }

      if (lockEvent.target !== target) {
        hoverEnd(lockEvent.detail);
      }
    };

    var unlockListener = function unlockListener(lockEvent) {
      if (disabled) {
        return;
      }

      if (lockEvent.target !== target) {
        hoverStart(lockEvent.detail);
      }
    };
    /**
     * Enter element
     */


    var enterListener = function enterListener(e) {
      if (disabled) {
        return;
      }

      if (getPointerType(e) !== 'touch') {
        if (bubbles === false) {
          (0, _dispatchCustomEvent.default)(target, lockEventType, {
            detail: e
          });
        }

        hoverStart(e); // Attach listeners on demand

        (0, _addEvent.addEvent)(target, lockEventType, lockListener, opts);
        (0, _addEvent.addEvent)(target, unlockEventType, unlockListener, opts);

        if (onHoverUpdate != null) {
          (0, _addEvent.addEvent)(target, moveEventType, moveListener, opts);
        }

        (0, _addEvent.addEvent)(target, leaveEventType, leaveListener, opts);
      }
    };
    /**
     * Move within element
     */


    var moveListener = function moveListener(e) {
      if (disabled) {
        return;
      }

      if (getPointerType(e) !== 'touch') {
        if (onHoverUpdate != null) {
          // Not all browsers have these properties
          if (e.x == null) {
            e.x = e.clientX;
          }

          if (e.y == null) {
            e.y = e.clientY;
          }

          onHoverUpdate(e);
        }
      }
    };
    /**
     * Leave element
     */


    var leaveListener = function leaveListener(e) {
      if (disabled) {
        return;
      }

      if (getPointerType(e) !== 'touch') {
        if (bubbles === false) {
          (0, _dispatchCustomEvent.default)(target, unlockEventType, {
            detail: e
          });
        }

        hoverEnd(e); // Remove on-demand listeners

        (0, _addEvent.removeEvent)(target, lockEventType, lockListener, opts);
        (0, _addEvent.removeEvent)(target, unlockEventType, unlockListener, opts);

        if (onHoverUpdate != null) {
          (0, _addEvent.removeEvent)(target, moveEventType, moveListener, opts);
        }

        (0, _addEvent.removeEvent)(target, leaveEventType, leaveListener, opts);
      }
    };
    /**
     * Start the hover gesture
     */


    var hoverStart = function hoverStart(e) {
      if (onHoverStart != null) {
        onHoverStart(e);
      }

      if (onHoverChange != null) {
        onHoverChange(true);
      }
    };
    /**
     * End the hover gesture
     */


    var hoverEnd = function hoverEnd(e) {
      if (onHoverEnd != null) {
        onHoverEnd(e);
      }

      if (onHoverChange != null) {
        onHoverChange(false);
      }
    };

    if (target !== null) {
      attachedNode.current = target;
      (0, _addEvent.addEvent)(target, enterEventType, enterListener, opts);
    } else if (attachedNode.current != null) {
      var node = attachedNode.current;
      (0, _addEvent.removeEvent)(node, lockEventType, lockListener, opts);
      (0, _addEvent.removeEvent)(node, unlockEventType, unlockListener, opts);
      (0, _addEvent.removeEvent)(node, enterEventType, enterListener, opts);
      (0, _addEvent.removeEvent)(node, moveEventType, moveListener, opts);
      (0, _addEvent.removeEvent)(node, leaveEventType, leaveListener, opts);
      attachedNode.current = null;
    }
  }, [canUsePE, bubbles, disabled, onHoverStart, onHoverChange, onHoverUpdate, onHoverEnd]);
}