"use strict";

exports.__esModule = true;
exports.useInteractOutside = useInteractOutside;

var _react = _interopRequireDefault(require("react"));

var _useEvent = require("../use-event");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
function useInteractOutside(config) {
  var disabled = config.disabled,
      onInteractOutside = config.onInteractOutside;
  var addClickListener = (0, _useEvent.useEvent)('click');
  return _react.default.useCallback(function (target) {
    // Determine if we should trigger an outside click
    var clickListener = function clickListener(e) {
      if (target != null && target instanceof HTMLElement && !target.contains(e.target)) {
        if (onInteractOutside != null) {
          onInteractOutside(e);
        }
      }
    };

    if (target != null) {
      addClickListener(document, !disabled && clickListener || null);
    }
  }, [addClickListener, disabled, onInteractOutside]);
}