"use strict";

exports.__esModule = true;
exports.useKeyboard = useKeyboard;

var _react = _interopRequireDefault(require("react"));

var _addEvent = require("../../modules/addEvent");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * useKeyboardEvents implementation
 */
var captureOptions = {
  capture: true
}; // TODO: https://github.com/w3c/uievents/issues/202

function useKeyboard(config) {
  var disabled = config.disabled,
      onKeyDown = config.onKeyDown,
      onKeyDownCapture = config.onKeyDownCapture,
      onKeyUp = config.onKeyUp,
      onKeyUpCapture = config.onKeyUpCapture;

  var attachedNode = _react.default.useRef(null);

  return _react.default.useCallback(function (target) {
    var createKeyListener = function createKeyListener(listener) {
      return function keyListener(e) {
        if (disabled) {
          return;
        } // Ignore composition events


        if (!e.isComposing && e.keyCode !== 229) {
          if (listener != null) {
            listener(e);
          }
        }
      };
    };

    var keyDownListener = createKeyListener(onKeyDown);
    var keyUpListener = createKeyListener(onKeyUp);
    var keyDownCaptureListener = createKeyListener(onKeyDownCapture);
    var keyUpCaptureListener = createKeyListener(onKeyUpCapture);

    if (target != null) {
      (0, _addEvent.addEvent)(target, 'keydown', keyDownListener);
      (0, _addEvent.addEvent)(target, 'keyup', keyUpListener);
      (0, _addEvent.addEvent)(target, 'keydown', keyDownCaptureListener, captureOptions);
      (0, _addEvent.addEvent)(target, 'keyup', keyUpCaptureListener, captureOptions);
    } else if (attachedNode.current != null) {
      var node = attachedNode.current;
      (0, _addEvent.removeEvent)(node, 'keydown', keyDownListener);
      (0, _addEvent.removeEvent)(node, 'keyup', keyUpListener);
      (0, _addEvent.removeEvent)(node, 'keydown', keyDownCaptureListener, captureOptions);
      (0, _addEvent.removeEvent)(node, 'keyup', keyUpCaptureListener, captureOptions);
      attachedNode.current = null;
    }
  }, [disabled, onKeyDown, onKeyDownCapture, onKeyUp, onKeyUpCapture]);
}