"use strict";

exports.__esModule = true;
exports.useResize = useResize;

var _react = _interopRequireDefault(require("react"));

var _supportsDOM = _interopRequireDefault(require("../../modules/supportsDOM"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var HANDLE_RESIZE_KEY = '__reactHandleResize';
var didWarn = false;
var resizeObserver = null;

function getResizeObserver() {
  if ((0, _supportsDOM.default)() && typeof window.ResizeObserver !== 'undefined') {
    if (resizeObserver == null) {
      resizeObserver = new window.ResizeObserver(function (entries) {
        entries.forEach(function (entry) {
          var handleResize = entry.target[HANDLE_RESIZE_KEY];

          if (handleResize != null) {
            handleResize(entry);
          }
        });
      });
    }
  } else if (process.env.NODE_ENV !== 'production' && process.env.NODE_ENV !== 'test') {
    if (!didWarn) {
      console.warn('onResize relies on ResizeObserver which is not supported by your browser. ' + 'Please include a polyfill, e.g., https://github.com/que-etc/resize-observer-polyfill.');
      didWarn = true;
    }
  }

  return resizeObserver;
} // TODO(#37): Support multiple uses


function useResize(config) {
  var observer = getResizeObserver();
  var _config$box = config.box,
      box = _config$box === void 0 ? 'border-box' : _config$box,
      onResize = config.onResize;

  var attachedNode = _react.default.useRef(null);

  return _react.default.useCallback(function (target) {
    if (target != null) {
      attachedNode.current = target;

      if (onResize != null) {
        target[HANDLE_RESIZE_KEY] = function (entry) {
          var borderBoxSize = entry.borderBoxSize,
              contentRect = entry.contentRect; // 'contentRect' is legacy but not deprecated, and it provides the same
          // values as 'contentBoxSize' in fewer btyes

          var blockSize = contentRect.height;
          var inlineSize = contentRect.width;

          if (box === 'border-box') {
            if (borderBoxSize != null) {
              // Firefox doesn't provide a sequence of boxes, even though the spec
              // defines this value as a frozen array
              var borderSize = borderBoxSize[0] || borderBoxSize;
              blockSize = borderSize.blockSize;
              inlineSize = borderSize.inlineSize;
            } else {
              // 'borderBoxSize' is not currently available in all engines and not
              // included in most polyfills, so we fallback to 'getBoundingClientRect'
              var borderRect = target.getBoundingClientRect();
              blockSize = borderRect.height;
              inlineSize = borderRect.width;
            }
          }

          onResize({
            blockSize: blockSize,
            inlineSize: inlineSize
          });
        };
      }

      if (observer != null) {
        if (typeof target[HANDLE_RESIZE_KEY] === 'function') {
          // $FlowExpectedError: the Flow type is wrong
          observer.observe(target);
        }
      }
    } else if (attachedNode.current && observer != null) {
      observer.unobserve(attachedNode.current);
      attachedNode.current = null;
    }
  }, [box, observer, onResize]);
}