/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
'use strict';

exports.__esModule = true;
exports.addEvent = addEvent;
exports.removeEvent = removeEvent;

var _supportsPassiveEvents = _interopRequireDefault(require("./supportsPassiveEvents"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var canUsePassiveEvents = (0, _supportsPassiveEvents.default)();

var emptyFunction = function emptyFunction() {};

var passiveByDefault = {
  touchstart: true,
  touchmove: true,
  scroll: true
};
/**
 * Normalize event options and default performance-sensitive events to passive.
 */

function getOptions(type, options) {
  if (options != null) {
    var capture = options.capture,
        passive = options.passive;

    if (canUsePassiveEvents) {
      return passive == null || passiveByDefault[type] === true ? {
        capture: capture,
        passive: true
      } : options;
    } else {
      return Boolean(capture);
    }
  }

  return false;
}
/**
 * Add the event listener using options normalization, SyntheticEvent
 * compatibility, and returning a function to remove the event listener.
 */


function addEvent(target, type, listener, options) {
  var opts = getOptions(type, options);

  if (listener != null) {
    var element = target;
    element.addEventListener(type, listener, opts);
    return function removeListener() {
      if (element != null) {
        element.removeEventListener(type, listener, opts);
      }
    };
  } else {
    return emptyFunction;
  }
}

function removeEvent(target, type, listener, options) {
  var opts = getOptions(type, options);

  if (listener != null) {
    var element = target;
    element.removeEventListener(type, listener, opts);
  }
}