"use strict";

exports.__esModule = true;
exports.default = useMediaQuery;

var _react = _interopRequireDefault(require("react"));

var _supportsDOM = _interopRequireDefault(require("./supportsDOM"));

var _useLayoutEffect = _interopRequireDefault(require("./useLayoutEffect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var canUseDOM = (0, _supportsDOM.default)();

function useMediaQuery(query) {
  var _React$useState = _react.default.useState(canUseDOM ? function () {
    return window.matchMedia(query).matches;
  } : false),
      state = _React$useState[0],
      setState = _React$useState[1];

  (0, _useLayoutEffect.default)(function () {
    if (canUseDOM) {
      var mediaQueryList = window.matchMedia(query);

      var listener = function listener() {
        setState(Boolean(mediaQueryList.matches));
      };

      mediaQueryList.addListener(listener);
      setState(mediaQueryList.matches);
      return function () {
        mediaQueryList.removeListener(listener);
      };
    }
  }, [query]);
  return state;
}

module.exports = exports.default;