# createElement

Create a fundamental element with built-in support for the core accessibility and style props. The module provides low-level tools that can be used to create custom "fundamental" components on the web. The core accessibility and styling props can be extracted from props by calling `filterProps`, and "unsafe" CSS resets can be created with `createStyleRule`.

### createElement(type, props)

This is the `react-gui` equivalent of `React.createElement`. It can be used to create your own custom components that support the `react-gui` accessibility and style props.

### createStyleRules(obj)

Define CSS to be used by the custom component. You should think of these styles as equivalent to "resets" or "UA styles". These styles are inserted above the styles generated by `StyleSheet` and aren't part of the "atomic" styles layer.

### filterProps(props)

Returns the common accessibility and style props (and removes all others), e.g., `accessibilityLabel`, `accessibilityRole`, `style`, etc. This can be useful when defing strict prop APIs for your components.

```js
import createElement, {createStyleRules, filterProps} from 'react-gui/create-element';

function View(props) {
  // Only the props recognized by 'createElement'
  const filteredProps = createProps(props);
  // Attach a CSS reset
  filteredProps.classList = [ css.base ]
  // Add specific props to forward to the DOM
  filteredProps.dir = props.direction;

  return createElement('div', filteredProps);
}

const css = createStyleRules({
  base: {
    display: 'flex',
    ...
  }
});
