/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow
 */

import type { EventOptions, Listener } from '#internal/addEvent';

import { addEvent } from '#internal/addEvent';

type EventHandle = (target: EventTarget, callback: ?Listener) => () => void;

/**
 * Return a handle for adding listeners of the given type to targets
 */
export function createEventHandle(
  type: string,
  options: ?EventOptions
): EventHandle {
  return function addListener(target: EventTarget, listener: ?Listener) {
    if (target == null || typeof target.addEventListener !== 'function') {
      throw new Error('createEventHandle: called on an invalid target.');
    }
    return addEvent(target, type, listener, options);
  };
}
