# use-event

Listen to arbitrary DOM events on an element. The hook returns an "addListener" function that accepts a target and listener. This function can be conditionally called (unlike hooks) and must be used within an event/ref callback or a `useEffect`/`useLayoutEffect` hook. The listener is automatically cleaned up when a component is cleaned up, but the return value of the "addListener" function is a "removeListener" function that can be used for manual cleanup.

Note that `touchstart`, `touchmove`, and `scroll` events are automatically made `passive` by default and calling `preventDefault()` will have no effect unless the options for these events explicitly set `passive` to `false`.

This hook can be used to create custom event hooks to complement the built-in event hooks.

```js
import useEvent from 'react-gui/use-event';

const options = { capture: false, passive: false };

function useClick(ref, { onClick }) {
  const addClickListener = useEvent('click', options);
  React.useLayoutEffect(() => {
    const node = ref.current;
    if (node != null) {
      // Listeners must be set in effects or event handlers
      addClickListener(node, onClick);
    }
  }, [addClickListener, onClick, ref]);
}
```
