/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow
 */

import React from 'react';
import { useEvent } from '../use-event';

export type InteractOutsideConfig = {
  disabled?: ?boolean,
  onInteractOutside?: (e: any) => void
};

export function useInteractOutside(config: InteractOutsideConfig) {
  const { disabled, onInteractOutside } = config;

  const addClickListener = useEvent('click');

  return React.useCallback(
    (target: any) => {
      // Determine if we should trigger an outside click
      const clickListener = (e) => {
        if (
          target != null &&
          target instanceof HTMLElement &&
          !target.contains(e.target)
        ) {
          if (onInteractOutside != null) {
            onInteractOutside(e);
          }
        }
      };
      if (target != null) {
        addClickListener(document, (!disabled && clickListener) || null);
      }
    },
    [addClickListener, disabled, onInteractOutside]
  );
}
