# use-press

Listen to pointer and keyboard "press" events on the element. This hook provides an accessible way to listen to press interactions from all modality types. The `onPress` event is equivalent to the native `click` event, which means it may be called in isolation (by assistive technology, etc.) and it may not be bookended by `onPressStart` and `onPressEnd`. However, it also addresses certain UX issues related to click interactions. For example, if text is selected by a moving pointer while it is pressing, the press event is cancelled and the native behavior is prevented. This ensures that users can select text in a pressable region without triggering a press or navigation. A non-moving long press will have the same effect, as well as cancelling the native context menu on mobile. (This hook is implemented with `useResponder` and `useKeyboard`.)

```js
import usePress from 'react-gui/use-press';

usePress(ref, {
  delayLongPress,
  disabled,
  onLongPress,
  onPress,
  onPressCancel,
  onPressChange,
  onPressStart,
  onPressEnd,
  touchAction
});
```

Use `onPressChange` as a convenient way to listen to changes in the press state.

```js
import usePress from 'react-gui/use-press';

function usePressState(ref, { touchAction }) {
  const [pressed, onPressChange] = React.useState(false);
  usePress(ref, { onPressChange });
  return pressed;
}
```

## Types

```js
type PressConfig = $ReadOnly<{|
  delayLongPress?: ?number,
  disabled?: ?boolean,
  onLongPress?: ?(e: any) => void,
  onPress?: ?(e: any) => void,
  onPressCancel?: ?(e: any) => void,
  onPressChange?: ?(isPressed: boolean) => void,
  onPressEnd?: (e: any) => void,
  onPressStart?: (e: any) => void,
  touchAction?: TouchActionValue
|}>;
```
