/**
 * Copyright (c) Nicolas Gallagher
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow
 */

/**
 * Hook for integrating the Responder System into React
 *
 *   function SomeComponent({ onStartShouldSetResponder }) {
 *     const ref = useRef(null);
 *     useResponderEvents(ref, { onStartShouldSetResponder });
 *     return <div ref={ref} />
 *   }
 */

import type { ResponderConfig } from './ResponderSystem';

import React, { useDebugValue } from 'react';
import ResponderSystem from './ResponderSystem';

export function terminateResponder() {
  ResponderSystem.terminateResponder();
}

export function useResponder(config: ?ResponderConfig) {
  useDebugValue(config);

  // Set the config as necessary
  return React.useCallback(
    (target: any) => {
      if (target != null) {
        ResponderSystem.attachListeners();
        ResponderSystem.setConfig(target, config);
      }
    },
    [config]
  );
}
