/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @flow
 */

import type { ElementRef } from 'react';

export default function mergeRefs(...args: $ReadOnlyArray<ElementRef<any>>) {
  return function forwardRef(node: HTMLElement | null) {
    args.forEach((ref: ElementRef<any>) => {
      if (ref == null) {
        return;
      }
      if (typeof ref === 'function') {
        ref(node);
        return;
      }
      if (typeof ref === 'object') {
        ref.current = node;
        return;
      }
      console.error(
        `mergeRefs cannot handle refs of type boolean, number, or string. Received ref ${String(
          ref
        )}`
      );
    });
  };
}
